# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.paginatedansible_role_remote_response_list import PaginatedansibleRoleRemoteResponseList

class TestPaginatedansibleRoleRemoteResponseList(unittest.TestCase):
    """PaginatedansibleRoleRemoteResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedansibleRoleRemoteResponseList:
        """Test PaginatedansibleRoleRemoteResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedansibleRoleRemoteResponseList`
        """
        model = PaginatedansibleRoleRemoteResponseList()
        if include_optional:
            return PaginatedansibleRoleRemoteResponseList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/role_remote_response.ansible.RoleRemoteResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        url = '', 
                        ca_cert = '', 
                        client_cert = '', 
                        tls_validation = True, 
                        proxy_url = '', 
                        pulp_labels = {
                            'key' : ''
                            }, 
                        download_concurrency = 56, 
                        max_retries = 56, 
                        policy = null, 
                        total_timeout = 0.0, 
                        connect_timeout = 0.0, 
                        sock_connect_timeout = 0.0, 
                        sock_read_timeout = 0.0, 
                        headers = [
                            None
                            ], 
                        rate_limit = 56, 
                        hidden_fields = [
                            pulpcore.client.pulp_ansible.models.ansible_collection_remote_response_hidden_fields_inner.ansible_CollectionRemoteResponse_hidden_fields_inner(
                                name = '', 
                                is_set = True, )
                            ], )
                    ]
            )
        else:
            return PaginatedansibleRoleRemoteResponseList(
                count = 123,
                results = [
                    pulpcore.client.pulp_ansible.models.ansible/role_remote_response.ansible.RoleRemoteResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        url = '', 
                        ca_cert = '', 
                        client_cert = '', 
                        tls_validation = True, 
                        proxy_url = '', 
                        pulp_labels = {
                            'key' : ''
                            }, 
                        download_concurrency = 56, 
                        max_retries = 56, 
                        policy = null, 
                        total_timeout = 0.0, 
                        connect_timeout = 0.0, 
                        sock_connect_timeout = 0.0, 
                        sock_read_timeout = 0.0, 
                        headers = [
                            None
                            ], 
                        rate_limit = 56, 
                        hidden_fields = [
                            pulpcore.client.pulp_ansible.models.ansible_collection_remote_response_hidden_fields_inner.ansible_CollectionRemoteResponse_hidden_fields_inner(
                                name = '', 
                                is_set = True, )
                            ], )
                    ],
        )
        """

    def testPaginatedansibleRoleRemoteResponseList(self):
        """Test PaginatedansibleRoleRemoteResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
