# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_ansible.models.ansible_ansible_namespace_metadata import AnsibleAnsibleNamespaceMetadata

class TestAnsibleAnsibleNamespaceMetadata(unittest.TestCase):
    """AnsibleAnsibleNamespaceMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnsibleAnsibleNamespaceMetadata:
        """Test AnsibleAnsibleNamespaceMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnsibleAnsibleNamespaceMetadata`
        """
        model = AnsibleAnsibleNamespaceMetadata()
        if include_optional:
            return AnsibleAnsibleNamespaceMetadata(
                name = 'jUtgswwmejtcmosllnyulewqtzioitixmooyscslvdntrddzxydswqltrttwkqzbunjxbelktnh7nzn3yp7d8tmo8zxed012',
                company = '',
                email = '',
                description = '',
                resources = '',
                links = [
                    pulpcore.client.pulp_ansible.models.namespace_link.NamespaceLink(
                        url = '0', 
                        name = '0', )
                    ],
                avatar = bytes(b'blah')
            )
        else:
            return AnsibleAnsibleNamespaceMetadata(
                name = 'jUtgswwmejtcmosllnyulewqtzioitixmooyscslvdntrddzxydswqltrttwkqzbunjxbelktnh7nzn3yp7d8tmo8zxed012',
        )
        """

    def testAnsibleAnsibleNamespaceMetadata(self):
        """Test AnsibleAnsibleNamespaceMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
